Learn R Programming

valr (version 0.5.0)

bed12_to_exons: Convert BED12 to individual exons in BED6.

Description

After conversion to BED6 format, the score column contains the exon number, with respect to strand (i.e., the first exon for - strand genes will have larger start and end coordinates).

Usage

bed12_to_exons(x)

Arguments

See Also

Other utilities: bed_makewindows, bound_intervals, flip_strands, interval_spacing

Examples

Run this code
# NOT RUN {
x <- read_bed12(valr_example('mm9.refGene.bed.gz'))

bed12_to_exons(x)

# }

Run the code above in your browser using DataLab