Learn R Programming

valr (version 0.5.0)

bed_fisher: Fisher's test to measure overlap between two sets of intervals.

Description

Calculate Fisher's test on number of intervals that are shared and unique between two sets of x and y intervals.

Usage

bed_fisher(x, y, genome)

Arguments

Value

tbl_interval()

Details

Interval statistics can be used in combination with dplyr::group_by() and dplyr::do() to calculate statistics for subsets of data. See vignette('interval-stats') for examples.

See Also

http://bedtools.readthedocs.org/en/latest/content/tools/fisher.html

Other interval statistics: bed_absdist, bed_jaccard, bed_projection, bed_reldist

Examples

Run this code
# NOT RUN {
genome <- read_genome(valr_example('hg19.chrom.sizes.gz'))

x <- bed_random(genome, seed = 1010486)
y <- bed_random(genome, seed = 9203911)

bed_fisher(x, y, genome)

# }

Run the code above in your browser using DataLab