Learn R Programming

valr (version 0.5.0)

read_genome: Read genome files.

Description

Genome files (UCSC "chromSize" files) contain chromosome name and size information. These sizes are used by downstream functions to identify computed intervals that have coordinates outside of the genome bounds.

Usage

read_genome(path)

Arguments

path

containing chrom/contig names and sizes, one-pair-per-line, tab-delimited

Value

tbl_genome(), sorted by size

See Also

Other read functions: read_bed, read_vcf

Examples

Run this code
# NOT RUN {
read_genome(valr_example('hg19.chrom.sizes.gz'))

# }
# NOT RUN {
# `read_genome` accepts a URL
read_genome('https://genome.ucsc.edu/goldenpath/help/hg19.chrom.sizes')
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab