Genome files (UCSC "chromSize" files) contain chromosome name and size
information. These sizes are used by downstream functions to identify
computed intervals that have coordinates outside of the genome bounds.
Usage
read_genome(path)
Arguments
path
containing chrom/contig names and sizes, one-pair-per-line,
tab-delimited
# NOT RUN {read_genome(valr_example('hg19.chrom.sizes.gz'))
# }# NOT RUN {# `read_genome` accepts a URLread_genome('https://genome.ucsc.edu/goldenpath/help/hg19.chrom.sizes')
# }# NOT RUN {# }